==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/service/system-diagnostics.service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Client } from './client.service';

@Injectable({ providedIn: 'root' })
export class SystemDiagnosticsService {
    private static readonly API: string = '../nifi-api';

    constructor(
        private httpClient: HttpClient,
        private client: Client
    ) {}

    getSystemDiagnostics(nodewise?: boolean) {
        if (nodewise) {
            const params = {
                nodewise: true
            };
            return this.httpClient.get(`${SystemDiagnosticsService.API}/system-diagnostics`, { params });
        }
        return this.httpClient.get(`${SystemDiagnosticsService.API}/system-diagnostics`);
    }
}

==> nifi-2.7.1-source-release.zip: nifi-2.7.1/nifi-frontend/src/main/frontend/apps/nifi/src/app/service/system-diagnostics.service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable, inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Client } from './client.service';

@Injectable({ providedIn: 'root' })
export class SystemDiagnosticsService {
    private httpClient = inject(HttpClient);
    private client = inject(Client);

    private static readonly API: string = '../nifi-api';

    getSystemDiagnostics(nodewise?: boolean) {
        if (nodewise) {
            const params = {
                nodewise: true
            };
            return this.httpClient.get(`${SystemDiagnosticsService.API}/system-diagnostics`, { params });
        }
        return this.httpClient.get(`${SystemDiagnosticsService.API}/system-diagnostics`);
    }
}
